SystemOrganization addCategory: #'RSS-Core'!
SystemOrganization addCategory: #'RSS-Core-Model'!
SystemOrganization addCategory: #'RSS-Core-Tags'!

WAEntryPoint subclass: #RRRssHandler
	instanceVariableNames: 'rootComponentClass openDebugger'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core'!

!RRRssHandler class methodsFor: 'accessing' stamp: 'pmm 4/9/2007 13:48'!
description
	^'RSS feed'! !

!RRRssHandler methodsFor: 'accessing' stamp: 'lr 2/10/2008 15:45'!
configurationComponent
	^ RRHandlerEditor on: self! !

!RRRssHandler methodsFor: 'private' stamp: 'pmm 11/26/2007 22:40'!
createRootComponent
	^self rootComponentClass new! !

!RRRssHandler methodsFor: 'processing' stamp: 'pmm 7/16/2008 18:35'!
handleRequest: aRequest 
	| response document context canvas root rootComponent |
	response := WAResponse new contentType: RRRssRoot defaultContentType.
	document := self newDocumentOn: response stream.
	root := RRRssRoot new.
	document open: root.
	context := WARenderingContext new document: document.
	canvas := RRRssRenderCanvas 
		context: context
		callbacks: Dictionary new.
	rootComponent := self createRootComponent.
	WARequestContext 
		pushRequestHandler: self
		while: 
			[ 
			[ rootComponent initialRequest: aRequest.
			rootComponent updateRoot: aRequest.
			canvas render: rootComponent ] 
				on: Error
				do: [ :err |
					self openDebugger 
						ifTrue: [ SeasidePlatformSupport openDebuggerOn: err ]
						ifFalse: [ response := WAResponse internalError: err ] ] ].
	document close: root.
	^ response! !

!RRRssHandler methodsFor: 'initialize-release' stamp: 'pmm 4/9/2007 18:54'!
initialize
	super initialize.
	self openDebugger: true! !

!RRRssHandler methodsFor: 'accessing' stamp: 'pmm 4/9/2007 18:53'!
openDebugger
	^openDebugger! !

!RRRssHandler methodsFor: 'accessing' stamp: 'pmm 4/9/2007 18:54'!
openDebugger: aBoolean 
	openDebugger := aBoolean! !

!RRRssHandler methodsFor: 'accessing' stamp: 'pmm 11/26/2007 22:39'!
rootComponentClass
	^ rootComponentClass! !

!RRRssHandler methodsFor: 'accessing' stamp: 'pmm 11/26/2007 22:39'!
rootComponentClass: aClass
	rootComponentClass := aClass! !

WARoot subclass: #RRRssRoot
	instanceVariableNames: 'rssAttrs channelAttrs styles charSet'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core'!

!RRRssRoot class methodsFor: 'instance creation' stamp: 'pmm 8/16/2007 23:00'!
context: aRenderingContext
	^ self new! !

!RRRssRoot class methodsFor: 'accessing' stamp: 'pmm 4/9/2007 13:33'!
defaultCharSet
	^'utf-8'! !

!RRRssRoot class methodsFor: 'accessing' stamp: 'pmm 11/25/2007 15:47'!
defaultContentType
	^'application/rss+xml' toMimeType! !

!RRRssRoot methodsFor: 'accessing' stamp: 'pmm 4/9/2007 13:31'!
channelAttrs
	^channelAttrs! !

!RRRssRoot methodsFor: 'accessing' stamp: 'pmm 9/5/2007 22:40'!
charSet
	charSet isNil ifTrue: [
		charSet := self class defaultCharSet ].
	^charSet! !

!RRRssRoot methodsFor: 'accessing' stamp: 'pmm 9/5/2007 22:41'!
charSet: aString
	charSet := aString! !

!RRRssRoot methodsFor: 'writing' stamp: 'pmm 4/9/2007 20:21'!
close: aDocument
	self writeFootOn: aDocument! !

!RRRssRoot methodsFor: 'accessing' stamp: 'pmm 11/25/2007 16:02'!
contentType
	^self class defaultContentType
	! !

!RRRssRoot methodsFor: 'initialize-release' stamp: 'pmm 4/9/2007 13:30'!
initialize
	
	super initialize.
	rssAttrs := WAHtmlAttributes new
		at: 'version' put: '2.0';
		at: 'xmlns:content' put: 'http://purl.org/rss/1.0/modules/content/';
		at: 'xmlns:wfw' put: 'http://wellformedweb.org/CommentAPI/';
		at: 'xmlns:dc' put: 'http://purl.org/dc/elements/1.1/';
		yourself.
	channelAttrs := WAHtmlAttributes new.! !

!RRRssRoot methodsFor: 'writing' stamp: 'pmm 4/9/2007 20:21'!
open: aDocument
	self writeHeadOn: aDocument! !

!RRRssRoot methodsFor: 'accessing' stamp: 'pmm 4/9/2007 13:31'!
rssAttrs
	^rssAttrs! !

!RRRssRoot methodsFor: 'accessing' stamp: 'pmm 4/20/2007 23:23'!
styles
	styles isNil ifTrue: [
		styles := OrderedCollection new ].
	^styles! !

!RRRssRoot methodsFor: 'elements' stamp: 'pmm 5/31/2008 18:52'!
stylesheet
	"http://interglacial.com/~sburke/stuff/pretty_rss.html"
	^ self styles add: (RRXmlStyleSheet root: self)! !

!RRRssRoot methodsFor: 'writing' stamp: 'pmm 4/9/2007 13:19'!
writeFootOn: aDocument
	aDocument closeTag: 'channel'.
	aDocument closeTag: 'rss'! !

!RRRssRoot methodsFor: 'writing' stamp: 'pmm 4/1/2008 06:51'!
writeHeadOn: aDocument
	self writePreambleOn: aDocument.
	self writeStylesOn: aDocument.
	
	aDocument openTag: 'rss' attributes: rssAttrs.
	aDocument openTag: 'channel' attributes: channelAttrs.! !

!RRRssRoot methodsFor: 'writing' stamp: 'pmm 4/1/2008 06:50'!
writePreambleOn: aDocument
	aDocument nextPutAll: '<?xml version="1.0" encoding="'.
	aDocument nextPutAll: self charSet.
	aDocument nextPutAll: '"?>'! !

!RRRssRoot methodsFor: 'writing' stamp: 'pmm 4/20/2007 23:26'!
writeStylesOn: aDocument
	styles isNil ifTrue: [ ^self ].

	styles do: [ :each |
		aDocument print: each ]! !

WAContentElement subclass: #RRXmlStyleSheet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core'!

!RRXmlStyleSheet methodsFor: 'attributes' stamp: 'pmm 5/31/2008 18:51'!
beCss
	self type: 'text/css' toMimeType! !

!RRXmlStyleSheet methodsFor: 'attributes' stamp: 'pmm 5/31/2008 18:51'!
beXsl
	self type: 'text/xsl' toMimeType! !

!RRXmlStyleSheet methodsFor: 'printing' stamp: 'pmm 5/31/2008 18:53'!
encodeOn: aDocument
	aDocument nextPutAll: '<?xml-stylesheet'.
	
	attributes encodeOn: aDocument.
	self childrenDo: [ :each | each encodeOn: aDocument ].
	
	aDocument nextPutAll: '?>'! !

!RRXmlStyleSheet methodsFor: 'accessing' stamp: 'pmm 4/21/2007 00:17'!
tag
	self shouldNotImplement! !

!RRXmlStyleSheet methodsFor: 'attributes' stamp: 'pmm 5/31/2008 18:50'!
url: aString
	self attributeAt: 'href' put: aString! !

WAConfigurationEditor subclass: #RRHandlerEditor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core'!

!RRHandlerEditor methodsFor: 'rendering' stamp: 'pmm 11/26/2007 22:39'!
renderFormOn: html
	html heading level1; with: 'Configuration'.
	html table: [
		html tableRow: [
			html tableHeading: 'Root Component'.
			html tableData: [
				html select
					list: self rootComponents;
					on: #rootComponentClass of: self handler ] ].
		html tableRow: [
			html tableHeading: 'Open Debugger on Errors'.
			html tableData: [
				html checkbox
					on: #openDebugger of: self handler ] ] ]! !

!RRHandlerEditor methodsFor: 'accessing' stamp: 'pmm 11/26/2007 22:23'!
rootComponents
	^(RRComponent allSubclasses select: [ :each | each canBeRoot ])
		asSortedCollection: [ :a :b | a name <= b name ]! !

WACanvas subclass: #RRRssRenderCanvas
	instanceVariableNames: 'context'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core'!

!RRRssRenderCanvas commentStamp: 'pmm 4/11/2007 21:29' prior: 0!
Structure of an RSS Document
Elements with a star (*) at the beginning are required. Elements with a plus sign (+) are an extension. Channel is automatically open.

channel
	*title
	*link
	*description
	language
	copyright
	managingEditor
	webMaster
	publicationDate
	lastBuildDate
	category
	generator
	documentation
	cloud
	timeToLive
	image
		*url
		*title
		*link
		width
		height
		description
	rating
	textInput
		*title
		*description
		*name
		*link
	skipHours
		hour
	skipDays
		day
	item
		*title
		*link
		*description
		author
		category
		comments
		enclosure
		guid
		publicationDate
		source
		+creator
		+comment
		+commentRss
		+contentEncoded
		
Email Addresses:
Email addresses must conform to RFC 2822
Convert the email address to a valid form. Examples of valid email addresses:
    * joesmith@example.com
    * joesmith@example.com (Joe Smith)
    * Joe Smith <joesmith@example.com>
    * joesmith.nospamplease@nospam.example.com
You can either:
- use correctly formatted strings
- implement #displayString in your domain email address class so that it return a string in a valid form
- implement #renderOn: in your domain  email address class so that it renders a string in a valid form
- use RREmailAddress

date times:
The value specified must meet the Date and Time specifications as defined by RFC822, with the exception that the year should be expressed as four digits.
Here are examples of valid RFC822 date-times:
Wed, 02 Oct 2002 08:00:00 EST
Wed, 02 Oct 2002 13:00:00 GMT
Wed, 02 Oct 2002 15:00:00 +0200

If you use Chronos you can use
printStringUsing: printStringUsing: ChronosPrintPolicy rfc822
Else you can use RRRfc822DateTime.

Here is an example of an invalid RFC822 date-time:
2002-10-02T08:00:00-05:00
!

!RRRssRenderCanvas class methodsFor: 'instance creation' stamp: 'pmm 8/16/2007 23:00'!
builder
	^super builder
		rootClass: RRRssRoot;
		yourself! !

!RRRssRenderCanvas class methodsFor: 'instance creation' stamp: 'pmm 9/25/2006 16:22'!
context: aRenderingContext callbacks: aCallbackStore
	^ self basicNew initializeWithContext: aRenderingContext callbacks: aCallbackStore! !

!RRRssRenderCanvas class methodsFor: 'generating-tags' stamp: 'pmm 9/22/2006 15:20'!
generateBinaryFor: aCollection
	(aCollection size = 4 and: [(self includesSelector: aCollection third) not]) ifTrue: [
		self 
			compile: aCollection third, ' aBlock
	self ', aCollection second, ' with: aBlock'
			classified: aCollection fourth]! !

!RRRssRenderCanvas class methodsFor: 'accessing-tags' stamp: 'pmm 9/29/2006 00:55'!
tags
	"
	self generateTags
	"

	^ #(
		('item' item item: 'item')
	
		('title' title title: 'channel-required')
		('link' link link: 'channel-required')
		('description' description description: 'channel-required')

		
		('language' language language: 'channel-optional')
		('copyright' copyright copyright: 'channel-optional')
		('managingEditor' managingEditor managingEditor: 'channel-optional')
		('webMaster' webMaster webMaster: 'channel-optional')
		('pubDate' publicationDate publicationDate: 'channel-optional')
		('lastBuildDate' lastBuildDate lastBuildDate: 'channel-optional')
		('category' category category: 'channel-optional')
		('generator' generator generator: 'channel-optional')
		('docs' documentation documentation: 'channel-optional')
		('cloud' cloud cloud: 'channel-optional')
		('ttl' timeToLive timeToLive: 'channel-optional')
		('image' image image: 'channel-optional')
		('rating' rating rating: 'channel-optional')
		('textInput' textInput textInput: 'channel-optional')
		('skipHours' skipHours skipHours: 'channel-optional')
		('skipDays' skipDays skipDays: 'channel-optional')
		
		('author' author author: 'item-optional')
		('comments' comments comments: 'item-optional')
		('enclosure' enclosure enclosure: 'item-optional')
		('guid' guid guid: 'item-optional')
		('source' source source: 'item-optional')
		('language' language language: 'item-optional')
		
		('width' width width: 'image-optional')
		('height' height height: 'image-optional')
		
		('name' name name: 'textinput-required')
		
		('hour' hour hour: 'skipHours')
		('day' day day: 'skipDays')
		
		('url' url url: 'image')
		)! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/29/2006 11:34'!
author
	"Email address of the author of the item.
	
	It's the email address of the author of the item. For newspapers and magazines syndicating via RSS, the author is the person who wrote the article that the <item> describes. For collaborative weblogs, the author of the item might be different from the managing editor or webmaster. For a weblog authored by a single individual it would make sense to omit the <author> element."
	^ self tag: 'author'! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/22/2006 14:56'!
author: aBlock
	self author with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 11:49'!
category
	"---- as optional subelement of channel ----
	Specify one or more categories that the channel belongs to. Follows the same rules as the <item>-level category element below.
	
	---- as optional subelement of item ----
	Includes the item in one or more categories.
	
	The value of the element is a forward-slash-separated string that identifies a hierarchic location in the indicated taxonomy. Processors may establish conventions for the interpretation of categories.
	
	You may include as many category elements as you need to, for different domains, and to have an item cross-referenced in different parts of the same domain.
	
	It has one optional attribute, domain, a string that identifies a categorization taxonomy.
	
	In RSS 2.0, a provision is made for linking a channel to its identifier in a cataloging system, using the channel-level category feature, described above. For example, to link a channel to its Syndic8 identifier, include a category element as a sub-element of <channel>, with domain 'Syndic8', and value the identifier for your channel in the Syndic8 database. The appropriate category element for Scripting News would be
	
	rss category
		domain: 'Syndic8';
		with: 1765"
	^ self brush: RRCategoryTag new! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
category: aBlock
	self category with: aBlock! !

!RRRssRenderCanvas methodsFor: 'convenience' stamp: 'pmm 4/9/2007 11:33'!
cdata: aString
	"aString must not include ']]>'
	
	Google says if there is an error in the feed, there is a 0.02% chance
	that this is the cause, combined with the fact that about 7% of all feeds
	have errors there is a (2 / 10000) * (7 / 100) chance this goes wrong.
	Do you deal in chance?
	
	http://googlereader.blogspot.com/2005/12/xml-errors-in-feeds.html"
	self flush.
	self document nextPutAll: '<!![CDATA['.
	self document nextPutAll: aString.
	self document nextPutAll: ']]>'! !

!RRRssRenderCanvas methodsFor: 'private' stamp: 'pmm 9/25/2006 16:28'!
close
	self flush! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:37'!
cloud
	"Allows processes to register with a cloud to be notified of updates to the channel, implementing a lightweight publish-subscribe protocol for RSS feeds.
	
	for more info see RRCloudTag"
	^ self brush: RRCloudTag new! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:56'!
cloud: aBlock
	self cloud with: aBlock! !

!RRRssRenderCanvas methodsFor: 'well-formed-web' stamp: 'pmm 2/23/2007 09:04'!
comment
	"This element appears in RSS feeds and contains the URI that comment entries are to be POSTed to. The details of this are outlined in the CommentAPI Specification (http://wellformedweb.org/story/9)"
	^self tag: 'wfw:comment'! !

!RRRssRenderCanvas methodsFor: 'private' stamp: 'lr 2/28/2007 09:28'!
comment: aString! !

!RRRssRenderCanvas methodsFor: 'well-formed-web' stamp: 'pmm 2/23/2007 09:06'!
commentRss
	"This element also appears in RSS feeds and contains the URI of the RSS feed for comments on that Item. This is documented in Chris Sells' Specification(http://www.sellsbrothers.com/spout/default.aspx?content=archive.htm#exposingRssComments). Note that for quite a while this page has had a typo and erroneously referred to this element as 'commentRSS' as opposed to the correct 'commentRss'. Feed consumers should be aware that they may run into both spellings in the wild. Please see this page (http://www.intertwingly.net/blog/2006/04/16/commentRss) for more information."
	^self tag: 'wfw:commentRss'! !

!RRRssRenderCanvas methodsFor: 'well-formed-web' stamp: 'pmm 2/23/2007 09:06'!
commentRss: aBlock
	^self commentRss with: aBlock! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/29/2006 11:37'!
comments
	"URL of a page for comments relating to the item.
	
	If present, it is the url of the comments page for the item."
	^ self tag: 'comments'! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/22/2006 14:56'!
comments: aBlock
	self comments with: aBlock! !

!RRRssRenderCanvas methodsFor: 'content' stamp: 'pmm 2/22/2007 22:48'!
contentEncoded
	"A module for the actual content of websites, in multiple formats.
	http://web.resource.org/rss/1.0/modules/content/
	
	example:
	rss contentEncoded: '<p>What a <em>beautiful</em> day!!</p>'"
	^ self tag: 'content:encoded'! !

!RRRssRenderCanvas methodsFor: 'content' stamp: 'pmm 2/23/2007 09:25'!
contentEncoded: aString
	"A module for the actual content of websites.
	
	aString must not include ']]>'"
	self contentEncoded
		with: [ self cdata: aString ]! !

!RRRssRenderCanvas methodsFor: 'accessing' stamp: 'pmm 9/25/2006 16:25'!
context
	^context! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/27/2006 11:07'!
copyright
	"Copyright notice for content in the channel."
	^ self tag: 'copyright'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
copyright: aBlock
	self copyright with: aBlock! !

!RRRssRenderCanvas methodsFor: 'dublin-core' stamp: 'pmm 2/23/2007 08:58'!
creator
	"An entity primarily responsible for making the resource.
	Examples of a Creator include a person, an organization, or a service. Typically, the name of a Creator should be used to indicate the entity.
	
	http://dublincore.org/documents/dces/
	http://purl.org/dc/elements/1.1/creator"
	^ self tag: 'dc:creator'! !

!RRRssRenderCanvas methodsFor: 'dublin-core' stamp: 'pmm 2/23/2007 08:58'!
creator: aBlock
	self creator with: aBlock! !

!RRRssRenderCanvas methodsFor: 'skipDays' stamp: 'pmm 9/29/2006 00:56'!
day
	^ self brush: RRDayTag new! !

!RRRssRenderCanvas methodsFor: 'skipDays' stamp: 'pmm 9/29/2006 00:56'!
day: aBlock
	self day with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/23/2006 12:17'!
defaultDocumentation
	self documentation: 'http://www.rssboard.org/rss-specification'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:34'!
defaultGenerator
	self generator: self defaultGeneratorString! !

!RRRssRenderCanvas methodsFor: 'private' stamp: 'lr 2/28/2007 09:27'!
defaultGeneratorString
	^SeasidePlatformSupport defaultRSSGeneratorString! !

!RRRssRenderCanvas methodsFor: 'channel-required' stamp: 'pmm 9/29/2006 11:33'!
description
	"
	---- as required subelement of channel ----
	Phrase or sentence describing the channel.
	e.g.: 'The latest news from GoUpstate.com, a Spartanburg Herald-Journal Web site.'
	
	---- a required subelement of item ----
	The item synopsis.
	
	---- as required subelement of textInput ----
	Explains the text input area.
	
	----  as an optional subelement of image ----
	contains text that is included in the TITLE attribute of the link formed around the image in the HTML rendering."
	^ self tag: 'description'! !

!RRRssRenderCanvas methodsFor: 'channel-required' stamp: 'pmm 9/22/2006 14:56'!
description: aBlock
	self description with: aBlock! !

!RRRssRenderCanvas methodsFor: 'accessing' stamp: 'pmm 9/25/2006 16:24'!
document
	^self context document! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:36'!
documentation
	"A URL that points to the documentation for the format used in the RSS file. It's probably a pointer to this page. It's for people who might stumble across an RSS file on a Web server 25 years from now and wonder what it is.
	e.g. 'http://www.rssboard.org/rss-specification'
	see #defaultDocumentation"
	^ self tag: 'docs'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
documentation: aBlock
	self documentation with: aBlock! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/29/2006 11:47'!
enclosure
	"Describes a media object that is attached to the item.
	
	It has three required attributes. url says where the enclosure is located, length says how big it is in bytes, and type says what its type is, a standard MIME type.
	
	The url must be an http url.
	
	e.g.:
	rss enclosure
		url: 'http://www.scripting.com/mp3s/weatherReportSuite.mp3';
		length: 12216320;
		type: 'audio/mpeg'"
	^ self brush: RREnclosureTag new! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/22/2006 14:56'!
enclosure: aBlock
	self enclosure with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:36'!
generator
	"A string indicating the program used to generate the channel.
	e.g.: 'RSRSS-pmm.3'
	see #defaultGenerator"
	^ self tag: 'generator'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
generator: aBlock
	self generator with: aBlock! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/29/2006 12:02'!
guid
	"A string that uniquely identifies the item.
	
	guid stands for globally unique identifier. It's a string that uniquely identifies the item. When present, an aggregator may choose to use this string to determine if an item is new.
	
	e.g.: 'http://some.server.com/weblogItem3207'
	
	There are no rules for the syntax of a guid. Aggregators must view them as a string. It's up to the source of the feed to establish the uniqueness of the string.
	
	If the guid element has an attribute named isPermaLink with a value of true, the reader may assume that it is a permalink to the item, that is, a url that can be opened in a Web browser, that points to the full item described by the <item> element. An example:
	
	e.g.:
	rss guid
		bePermaLink;
		with: 'http://inessential.com/2002/09/01.php#a2'
		
	isPermaLink is optional, its default value is true. If its value is false, the guid may not be assumed to be a url, or a url to anything in particular."
	^ self brush: RRGuidTag new! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/22/2006 14:56'!
guid: aBlock
	self guid with: aBlock! !

!RRRssRenderCanvas methodsFor: 'image-optional' stamp: 'pmm 9/29/2006 11:29'!
height
	"Optional elements include <width> and <height>, numbers, indicating the width and height of the image in pixels.
	
	Maximum value for height is 400, default value is 31."
	^ self tag: 'height'! !

!RRRssRenderCanvas methodsFor: 'image-optional' stamp: 'pmm 9/22/2006 14:56'!
height: aBlock
	self height with: aBlock! !

!RRRssRenderCanvas methodsFor: 'skipHours' stamp: 'pmm 9/29/2006 00:56'!
hour
	^ self tag: 'hour'! !

!RRRssRenderCanvas methodsFor: 'skipHours' stamp: 'pmm 9/29/2006 00:56'!
hour: aBlock
	self hour with: aBlock! !

!RRRssRenderCanvas methodsFor: 'private' stamp: 'pmm 4/12/2007 20:39'!
html: aString
	self flush.
	self document nextPutAll: aString! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:45'!
image
	"Specifies a GIF, JPEG or PNG image that can be displayed with the channel.
	the following subelements are required:
		url
		title
		link
	the following subelements are optional:
		width
		height
		description
	"
	^ self tag: 'image'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
image: aBlock
	self image with: aBlock! !

!RRRssRenderCanvas methodsFor: 'initialize-release' stamp: 'pmm 4/1/2008 07:12'!
initializeWithContext: aRenderingContext callbacks: aCallbackStore
	context := aRenderingContext! !

!RRRssRenderCanvas methodsFor: 'item' stamp: 'pmm 9/22/2006 14:56'!
item
	^ self tag: 'item'! !

!RRRssRenderCanvas methodsFor: 'item' stamp: 'pmm 9/22/2006 14:56'!
item: aBlock
	self item with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/27/2006 11:05'!
language
	"The language the channel is written in. This allows aggregators to group all Italian language sites, for example, on a single page. A list of allowable values for this element, as provided by Netscape, is implemented in the 'languages-generated' protocl of RRLanguageTag. You may also use values defined by the W3C (http://www.w3.org/TR/REC-html40/struct/dirlang.html#langcodes)."
	^ self brush: RRLanguageTag new! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
language: aBlock
	self language with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:17'!
lastBuildDate
	"The last time the content of the channel changed.
	again an RFC 822 date like all the other dates
	e.g.: 'Sat, 07 Sep 2002 09:42:31 GMT'"
	^ self tag: 'lastBuildDate'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
lastBuildDate: aBlock
	self lastBuildDate with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-required' stamp: 'pmm 9/27/2006 11:02'!
link
	"---- as required subelement of channel ----
	The URL to the HTML website corresponding to the channel.
	e.g.: 'http://www.goupstate.com/'
	
	---- as required subelement of item ----
	The URL of the item.
	
	---- as required subelement of image ----
	is the URL of the site, when the channel is rendered, the image is a link to the site. (Note, in practice the image <title> and <link> should have the same value as the channel's <title> and <link>
	
	---- as required subelement of textInput ----
	The URL of the CGI script that processes text input requests."
	
	^ self tag: 'link'! !

!RRRssRenderCanvas methodsFor: 'channel-required' stamp: 'pmm 9/22/2006 14:56'!
link: aBlock
	self link with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/27/2006 11:28'!
managingEditor
	"Email address for person responsible for editorial content.
	e.g.: 'George Matesky <geo@herald.com>'"
	^ self tag: 'managingEditor'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
managingEditor: aBlock
	self managingEditor with: aBlock! !

!RRRssRenderCanvas methodsFor: 'textinput-required' stamp: 'pmm 9/29/2006 11:31'!
name
	"The name of the text object in the text input area."
	^ self tag: 'name'! !

!RRRssRenderCanvas methodsFor: 'textinput-required' stamp: 'pmm 9/22/2006 14:56'!
name: aBlock
	self name with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 12:04'!
publicationDate
	"---- as optional subelement of channel ----
	The publication date for the content in the channel. For example, the New York Times publishes on a daily basis, the publication date flips once every 24 hours. That's when the pubDate of the channel changes. All date-times in RSS conform to the Date and Time Specification of RFC 822(http://asg.web.cmu.edu/rfc/rfc822.html#sec-5), with the exception that the year may be expressed with two characters or four characters (four preferred).
	
	---- as optional subelement of item ----
	Indicates when the item was published.
	Its value is a date, indicating when the item was published. If it's a date in the future, aggregators may choose to not display the item until that date.
	
	e.g: 'Sat, 07 Sep 2002 00:00:01 GMT'
	minimal: '20 Jun 82 23:59 EST'"
	^ self tag: 'pubDate'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
publicationDate: aBlock
	self publicationDate with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:47'!
rating
	"The PICS (http://www.w3.org/PICS/) rating for the channel."
	^ self tag: 'rating'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
rating: aBlock
	self rating with: aBlock! !

!RRRssRenderCanvas methodsFor: 'convenience' stamp: 'pmm 4/9/2007 19:42'!
renderContentEncoded: aOneArgumentBlock
	"renders the html content of an item
	a render canvas will be passed as an argument to the block"
	self contentEncoded
		with: [
			self renderHtml: aOneArgumentBlock ]! !

!RRRssRenderCanvas methodsFor: 'convenience' stamp: 'pmm 8/16/2007 22:49'!
renderHtml: aOneArgumentBlock
	"convenvience method to render html
	aOneArgumentBlock will be passed an html canvas"
	self text: (WARenderCanvas builder render: aOneArgumentBlock)! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:53'!
skipDays
	"A hint for aggregators telling them which days they can skip.
	
	An XML element that contains up to seven <day> sub-elements whose value is Monday, Tuesday, Wednesday, Thursday, Friday, Saturday or Sunday. Aggregators may not read the channel during days listed in the skipDays element."
	^ self tag: 'skipDays'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
skipDays: aBlock
	self skipDays with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:50'!
skipHours
	"A hint for aggregators telling them which hours they can skip.
	
	An XML element that contains up to 24 <hour> sub-elements whose value is a number between 0 and 23, representing a time in GMT, when aggregators, if they support the feature, may not read the channel on hours listed in the skipHours element. The hour beginning at midnight is hour zero."
	^ self tag: 'skipHours'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
skipHours: aBlock
	self skipHours with: aBlock! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/29/2006 12:07'!
source
	"The RSS channel that the item came from.
	
	Its value is the name of the RSS channel that the item came from, derived from its <title>. It has one required attribute, url, which links to the XMLization of the source.
	
	rss source
		url: 'http://www.tomalak.org/links2.xml';
		with: 'Tomalak''s Realm'
	
	The purpose of this element is to propagate credit for links, to publicize the sources of news items. It can be used in the Post command of an aggregator. It should be generated automatically when forwarding an item from an aggregator to a weblog authoring tool."
	^ self brush: RRSourceTag new! !

!RRRssRenderCanvas methodsFor: 'item-optional' stamp: 'pmm 9/22/2006 14:56'!
source: aBlock
	self source with: aBlock! !

!RRRssRenderCanvas methodsFor: 'convenience' stamp: 'pmm 11/26/2007 22:44'!
space
	self html: self spaceEntity! !

!RRRssRenderCanvas methodsFor: 'xml' stamp: 'mb 11/4/2006 10:23'!
spaceEntity
	^'&#160;'! !

!RRRssRenderCanvas methodsFor: 'private' stamp: 'pmm 2/23/2007 09:33'!
tag: aString
	"copy pasted from WAHtmlCanvas"
	^ self brush: (WAGenericTag tag: aString)! !

!RRRssRenderCanvas methodsFor: 'private' stamp: 'pmm 4/9/2007 11:31'!
text: anObject
	"copy pasted from WAHtmlCanvas"
	self document print: anObject! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:49'!
textInput
	"Specifies a text input box that can be displayed with the channel.
	The purpose of the <textInput> element is something of a mystery. You can use it to specify a search engine box. Or to allow a reader to provide feedback. Most aggregators ignore it.
	
	It has the following required subelements:
		title
		description
		name
		link"
	^ self tag: 'textInput'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
textInput: aBlock
	self textInput with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/29/2006 00:39'!
timeToLive
	"It's a number of minutes that indicates how long a channel can be cached before refreshing from the source. This makes it possible for RSS sources to be managed by a file-sharing network such as Gnutella.
	
	e.g.: 60"
	^ self tag: 'ttl'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
timeToLive: aBlock
	self timeToLive with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-required' stamp: 'pmm 9/27/2006 11:01'!
title
	"----- as required subelement of channel ----
	The name of the channel. It's how people refer to your service. If you have an HTML website that contains the same information as your RSS file, the title of your channel should be the same as the title of your website.
	e.g.: 'GoUpstate.com News Headlines'
	
	---- as required subelement of item ----
	The title of the item.
	
	---- as required subelement of image ----
	describes the image, it's used in the ALT attribute of the HTML <img> tag when the channel is rendered in HTML
	
	---- as required subelement of textInput ----
	The label of the Submit button in the text input area."
	
	^ self tag: 'title'! !

!RRRssRenderCanvas methodsFor: 'channel-required' stamp: 'pmm 9/22/2006 14:56'!
title: aBlock
	self title with: aBlock! !

!RRRssRenderCanvas methodsFor: 'image-required' stamp: 'pmm 9/29/2006 11:27'!
url
	"is the URL of a GIF, JPEG or PNG image that represents the channel."
	^ self tag: 'url'! !

!RRRssRenderCanvas methodsFor: 'image-required' stamp: 'pmm 9/29/2006 00:56'!
url: aBlock
	self url with: aBlock! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/27/2006 11:29'!
webMaster
	"Email address for person responsible for technical issues relating to channel.
	e.g.: 'Betty Guernsey <betty@herald.com>'"
	^ self tag: 'webMaster'! !

!RRRssRenderCanvas methodsFor: 'channel-optional' stamp: 'pmm 9/22/2006 14:56'!
webMaster: aBlock
	self webMaster with: aBlock! !

!RRRssRenderCanvas methodsFor: 'image-optional' stamp: 'pmm 9/29/2006 11:28'!
width
	"Optional elements include <width> and <height>, numbers, indicating the width and height of the image in pixels.
	
	Maximum value for width is 144, default value is 88."
	^ self tag: 'width'! !

!RRRssRenderCanvas methodsFor: 'image-optional' stamp: 'pmm 9/22/2006 14:56'!
width: aBlock
	self width with: aBlock! !

!RRRssRenderCanvas methodsFor: 'convenience' stamp: 'pmm 9/5/2007 23:06'!
withLineBreaks: aString
	aString isEmptyOrNil ifTrue: [ ^self ].
	self renderHtml: [ :html |
		html withLineBreaks: aString ]! !

WAPresenter subclass: #RRComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core'!

!RRComponent commentStamp: 'pmm 7/1/2007 22:01' prior: 0!
Base class for all RSS rendering components. Note that RSS components are stripped down versions of Seaside components. Many things like #call: don't work. Also #initialRequest: and #updateRoot: only get sent to the root component.!

!RRComponent class methodsFor: 'initialization' stamp: 'lr 3/25/2008 22:10'!
registerAsApplication: aString
	^ (RRRssHandler register: aString)
		rootComponentClass: self;
		yourself! !

!RRComponent methodsFor: 'rendering' stamp: 'pmm 4/9/2007 13:38'!
renderOn: aRenderer
	self renderWithContext: aRenderer context! !

!RRComponent methodsFor: 'rendering' stamp: 'pmm 9/22/2006 14:45'!
rendererClass
	^RRRssRenderCanvas! !

!RRComponent methodsFor: 'accessing' stamp: 'pmm 11/26/2007 22:48'!
session
	self shouldNotImplement! !

Object subclass: #RREmailAddress
	instanceVariableNames: 'username address'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Model'!

!RREmailAddress class methodsFor: 'instance creation' stamp: 'pmm 10/12/2006 23:35'!
address: aString
	^self new
		address: aString;
		yourself! !

!RREmailAddress class methodsFor: 'instance creation' stamp: 'pmm 10/12/2006 23:35'!
address: anAddressString username: aUsernameString
	^self new
		address: anAddressString;
		username: aUsernameString;
		yourself! !

!RREmailAddress methodsFor: 'accessing' stamp: 'pmm 10/12/2006 23:31'!
address
	^address! !

!RREmailAddress methodsFor: 'accessing' stamp: 'pmm 10/12/2006 23:31'!
address: anObject
	address := anObject! !

!RREmailAddress methodsFor: 'printing' stamp: 'pmm 11/21/2007 20:34'!
printOn: aStream
	super printOn: aStream.
	aStream nextPut: $(.
	aStream nextPutAll: self toString.
	aStream nextPut: $)! !

!RREmailAddress methodsFor: 'displaying' stamp: 'pmm 11/21/2007 20:34'!
toString
	^String streamContents: [ :stream |
		username isNil ifFalse: [
			stream
				nextPutAll: username;
				nextPutAll: ' <'].
		stream nextPutAll: address.
		username isNil ifFalse: [
			stream nextPut: $> ] ]! !

!RREmailAddress methodsFor: 'accessing' stamp: 'pmm 10/12/2006 23:31'!
username
	^username! !

!RREmailAddress methodsFor: 'accessing' stamp: 'pmm 10/12/2006 23:31'!
username: anObject
	username := anObject! !

Object subclass: #RRRfc822DateTime
	instanceVariableNames: 'dateAndTime timezoneString'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Model'!

!RRRfc822DateTime class methodsFor: 'instance creation' stamp: 'pmm 10/23/2006 10:14'!
dateAndTime: aDateAndTime timezoneString: aString
	^self new
		dateAndTime: aDateAndTime;
		timezoneString: aString;
		yourself! !

!RRRfc822DateTime class methodsFor: 'instance creation' stamp: 'pmm 10/23/2006 10:43'!
newDateAndTime: aDateAndTime
	^self
		newDateAndTime: aDateAndTime
		offset: aDateAndTime offset! !

!RRRfc822DateTime class methodsFor: 'instance creation' stamp: 'pmm 10/23/2006 10:32'!
newDateAndTime: aDateAndTime offset: aDuration
	^self
		dateAndTime: aDateAndTime
		timezoneString: (self offsetString:  aDuration)! !

!RRRfc822DateTime class methodsFor: 'instance creation' stamp: 'pmm 10/23/2006 11:01'!
newUtc: aDateAndTime
	^self
		dateAndTime: aDateAndTime asUTC
		timezoneString: 'UT'! !

!RRRfc822DateTime class methodsFor: 'private' stamp: 'pmm 10/23/2006 10:27'!
offsetString: aDuration
	^String streamContents: [ :stream |
		| positive |
		positive := aDuration asSeconds > 0
		 	or: [ aDuration asSeconds = 0
				and: [ aDuration nanoSeconds > 0 ] ].
		stream nextPut: (positive ifTrue: [ $+ ] ifFalse: [ $- ]).
		stream nextPutAll: (aDuration hours printPaddedWith: $0 to: 2).
		stream nextPutAll: (aDuration minutes printPaddedWith: $0 to: 2) ]! !

!RRRfc822DateTime methodsFor: 'accessing' stamp: 'pmm 10/23/2006 10:14'!
dateAndTime
	^dateAndTime! !

!RRRfc822DateTime methodsFor: 'accessing' stamp: 'pmm 10/23/2006 10:14'!
dateAndTime: anObject
	dateAndTime := anObject! !

!RRRfc822DateTime methodsFor: 'printing' stamp: 'pmm 11/21/2007 20:34'!
printString
	^String streamContents: [ :stream |
		stream
			nextPutAll: (dateAndTime dayOfWeekName first: 3);
			nextPutAll: ', ';
			nextPutAll: (dateAndTime dayOfMonth printPaddedWith: $0 to: 2);
			space;
			nextPutAll: (dateAndTime monthName first: 3);
			space;
			nextPutAll: dateAndTime year toString;
			space;
			nextPutAll: (dateAndTime hour24 printPaddedWith: $0 to: 2);
			nextPut: $:;
			nextPutAll: (dateAndTime minute printPaddedWith: $0 to: 2); 
			nextPut: $:;
			nextPutAll: (dateAndTime second printPaddedWith: $0 to: 2);
			space;
			nextPutAll: timezoneString ]! !

!RRRfc822DateTime methodsFor: 'accessing' stamp: 'pmm 10/23/2006 10:14'!
timezoneString
	^timezoneString! !

!RRRfc822DateTime methodsFor: 'accessing' stamp: 'pmm 10/23/2006 10:14'!
timezoneString: anObject
	timezoneString := anObject! !

WATagBrush subclass: #RRCategoryTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Tags'!

!RRCategoryTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:22'!
category: aString
	self attributeAt: 'category' put: aString! !

!RRCategoryTag methodsFor: 'accessing' stamp: 'pmm 9/29/2006 00:22'!
tag
	^'category'! !

WATagBrush subclass: #RRCloudTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Tags'!

!RRCloudTag commentStamp: 'pmm 9/22/2006 14:39' prior: 0!
<cloud> is an optional sub-element of <channel>.

It specifies a web service that supports the rssCloud interface which can be implemented in HTTP-POST, XML-RPC or SOAP 1.1.

Its purpose is to allow processes to register with a cloud to be notified of updates to the channel, implementing a lightweight publish-subscribe protocol for RSS feeds. 

A full explanation of this element and the rssCloud interface is here:
http://www.rssboard.org/rsscloud-interface!

!RRCloudTag class methodsFor: 'accessing-tags' stamp: 'pmm 9/22/2006 14:43'!
tags
	"
	self generateTags
	"

	^ #(
		('item' item item: 'item')
	
		('title' title title: 'channel-required')
		('link' link link: 'channel-required')
		('description' description description: 'channel-required')

		
		('language' language language: 'channel-optional')
		('copyright' copyright copyright: 'channel-optional')
		('managingEditor' managingEditor managingEditor: 'channel-optional')
		('webMaster' webMaster webMaster: 'channel-optional')
		('pubDate' publicationDate publicationDate: 'channel-optional')
		('lastBuildDate' lastBuildDate lastBuildDate: 'channel-optional')
		('category' category category: 'channel-optional')
		('generator' generator generator: 'channel-optional')
		('docs' documentation documentation: 'channel-optional')
		('cloud' cloud cloud: 'channel-optional')
		('ttl' timeToLive timeToLive: 'channel-optional')
		('image' image image: 'channel-optional')
		('rating' rating rating: 'channel-optional')
		('textInput' textInput textInput: 'channel-optional')
		('skipHours' skipHours skipHours: 'channel-optional')
		('skipDays' skipDays skipDays: 'channel-optional')
		
		('comments' comments comments: 'item-optional')
		('enclosure' enclosure enclosure: 'item-optional')
		('guid' guid guid: 'item-optional')
		
		('name' name name: 'image-required')
		
		)! !

!RRCloudTag methodsFor: 'protocols' stamp: 'pmm 9/22/2006 14:37'!
beSoap
	self protocol: 'soap'! !

!RRCloudTag methodsFor: 'protocols' stamp: 'pmm 9/22/2006 14:37'!
beXmlRpc
	self protocol: 'xml-rpc'! !

!RRCloudTag methodsFor: 'attributes' stamp: 'pmm 9/22/2006 14:34'!
domain: aString
	^self attributeAt: 'domain' put: aString! !

!RRCloudTag methodsFor: 'attributes' stamp: 'pmm 9/22/2006 14:35'!
path: aString
	^self attributeAt: 'path' put: aString! !

!RRCloudTag methodsFor: 'attributes' stamp: 'pmm 9/22/2006 14:35'!
port: anInteger
	^self attributeAt: 'port' put: anInteger! !

!RRCloudTag methodsFor: 'attributes' stamp: 'pmm 9/22/2006 14:37'!
protocol: aString
	^self attributeAt: 'protocol' put: aString! !

!RRCloudTag methodsFor: 'attributes' stamp: 'pmm 9/22/2006 14:35'!
registerProcedure: aString
	^self attributeAt: 'registerProcedure' put: aString! !

!RRCloudTag methodsFor: 'accessing' stamp: 'pmm 9/22/2006 14:34'!
tag
	^'cloud'! !

WATagBrush subclass: #RRDayTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Tags'!

!RRDayTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:52'!
monday
	^self with: 'Monday'! !

!RRDayTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:53'!
saturday
	^self with: 'Saturday'! !

!RRDayTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:53'!
sunday
	^self with: 'Sunday'! !

!RRDayTag methodsFor: 'accessing' stamp: 'pmm 9/29/2006 00:52'!
tag
	^'day'! !

!RRDayTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:52'!
thursday
	^self with: 'Thursday'! !

!RRDayTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:53'!
triday
	^self with: 'Friday'! !

!RRDayTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:52'!
tuesday
	^self with: 'Tuesday'! !

!RRDayTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 00:52'!
wednesday
	^self with: 'Wednesday'! !

WATagBrush subclass: #RREnclosureTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Tags'!

!RREnclosureTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 11:40'!
length: anInteger
	self attributeAt: 'length' put: anInteger! !

!RREnclosureTag methodsFor: 'accessing' stamp: 'pmm 9/29/2006 11:39'!
tag
	^'enclosure'! !

!RREnclosureTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 11:41'!
type: aString
	self attributeAt: 'type' put: aString! !

!RREnclosureTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 11:41'!
url: aString
	self attributeAt: 'url' put: aString! !

WATagBrush subclass: #RRGuidTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Tags'!

!RRGuidTag methodsFor: 'attributes' stamp: 'pmm 10/23/2006 10:52'!
beNoPermaLink
	self isPermaLink: false! !

!RRGuidTag methodsFor: 'attributes' stamp: 'pmm 10/23/2006 10:52'!
bePermaLink
	self isPermaLink: true! !

!RRGuidTag methodsFor: 'attributes' stamp: 'pmm 11/21/2007 20:34'!
isPermaLink: aBoolean
	"the value really must be a string else seaside makes
	isPermaLink='isPermaLink'"
	self attributeAt: 'isPermaLink' put: aBoolean toString! !

!RRGuidTag methodsFor: 'accessing' stamp: 'pmm 9/29/2006 12:00'!
tag
	^'guid'! !

WATagBrush subclass: #RRLanguageTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Tags'!

!RRLanguageTag class methodsFor: 'accessing' stamp: 'pmm 9/22/2006 15:16'!
codes
	^Array streamContents: [ :stream |
		self codesString lines do: [ :line |
			stream nextPut: (Array
				with: (line copyUpTo: Character tab) asLegalSelector
				with: (line copyAfter: Character tab)) ] ]! !

!RRLanguageTag class methodsFor: 'accessing' stamp: 'pmm 9/22/2006 15:09'!
codesString
	^
'Afrikaans	af
Albanian	sq
Basque	eu
Belarusian	be
Bulgarian	bg
Catalan	ca
Chinese (Simplified)	zh-cn
Chinese (Traditional)	zh-tw
Croatian	hr
Czech	cs
Danish	da
Dutch	nl
Dutch (Belgium)	nl-be
Dutch (Netherlands)	nl-nl
English	en
English (Australia)	en-au
English (Belize)	en-bz
English (Canada)	en-ca
English (Ireland)	en-ie
English (Jamaica)	en-jm
English (New Zealand)	en-nz
English (Phillipines)	en-ph
English (South Africa)	en-za
English (Trinidad)	en-tt
English (United Kingdom)	en-gb
English (United States)	en-us
English (Zimbabwe)	en-zw
Estonian	et
Faeroese	fo
Finnish	fi
French	fr
French (Belgium)	fr-be
French (Canada)	fr-ca
French (France)	fr-fr
French (Luxembourg)	fr-lu
French (Monaco)	fr-mc
French (Switzerland)	fr-ch
Galician	gl
Gaelic	gd
German	de
German (Austria)	de-at
German (Germany)	de-de
German (Liechtenstein)	de-li
German (Luxembourg)	de-lu
German (Switzerland)	de-ch
Greek	el
Hawaiian	haw
Hungarian	hu
Icelandic	is
Indonesian	in
Irish	ga
Italian	it
Italian (Italy)	it-it
Italian (Switzerland)	it-ch
Japanese	ja
Korean	ko
Macedonian	mk
Norwegian	no
Polish	pl
Portuguese	pt
Portuguese (Brazil)	pt-br
Portuguese (Portugal)	pt-pt
Romanian	ro
Romanian (Moldova)	ro-mo
Romanian (Romania)	ro-ro
Russian	ru
Russian (Moldova)	ru-mo
Russian (Russia)	ru-ru
Serbian	sr
Slovak	sk
Slovenian	sl
Spanish	es
Spanish (Argentina)	es-ar
Spanish (Bolivia)	es-bo
Spanish (Chile)	es-cl
Spanish (Colombia)	es-co
Spanish (Costa Rica)	es-cr
Spanish (Dominican Republic)	es-do
Spanish (Ecuador)	es-ec
Spanish (El Salvador)	es-sv
Spanish (Guatemala)	es-gt
Spanish (Honduras)	es-hn
Spanish (Mexico)	es-mx
Spanish (Nicaragua)	es-ni
Spanish (Panama)	es-pa
Spanish (Paraguay)	es-py
Spanish (Peru)	es-pe
Spanish (Puerto Rico)	es-pr
Spanish (Spain)	es-es
Spanish (Uruguay)	es-uy
Spanish (Venezuela)	es-ve
Swedish	sv
Swedish (Finland)	sv-fi
Swedish (Sweden)	sv-se
Turkish	tr
Ukranian	uk'! !

!RRLanguageTag class methodsFor: 'generating' stamp: 'pmm 9/22/2006 15:27'!
generateFor: aPair
	(self includesSelector: aPair first) ifFalse: [
		self 
			compile: aPair first, '
	self with: ''', aPair last, ''''
			classified: self generatedCategory ]! !

!RRLanguageTag class methodsFor: 'generating' stamp: 'pmm 9/22/2006 15:26'!
generateTags
	^self codes do: [ :each |
		self generateFor: each ]! !

!RRLanguageTag class methodsFor: 'accessing' stamp: 'pmm 9/22/2006 15:18'!
generatedCategory
	^'languages-generated'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
afrikaans
	self with: 'af'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
albanian
	self with: 'sq'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
basque
	self with: 'eu'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
belarusian
	self with: 'be'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
bulgarian
	self with: 'bg'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
catalan
	self with: 'ca'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
chineseSimplified
	self with: 'zh-cn'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
chineseTraditional
	self with: 'zh-tw'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
croatian
	self with: 'hr'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
czech
	self with: 'cs'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
danish
	self with: 'da'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
dutch
	self with: 'nl'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
dutchBelgium
	self with: 'nl-be'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
dutchNetherlands
	self with: 'nl-nl'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
english
	self with: 'en'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishAustralia
	self with: 'en-au'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishBelize
	self with: 'en-bz'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishCanada
	self with: 'en-ca'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishIreland
	self with: 'en-ie'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishJamaica
	self with: 'en-jm'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishNewZealand
	self with: 'en-nz'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishPhillipines
	self with: 'en-ph'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishSouthAfrica
	self with: 'en-za'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishTrinidad
	self with: 'en-tt'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishUnitedKingdom
	self with: 'en-gb'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishUnitedStates
	self with: 'en-us'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
englishZimbabwe
	self with: 'en-zw'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
estonian
	self with: 'et'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
faeroese
	self with: 'fo'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
finnish
	self with: 'fi'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
french
	self with: 'fr'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
frenchBelgium
	self with: 'fr-be'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
frenchCanada
	self with: 'fr-ca'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
frenchFrance
	self with: 'fr-fr'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
frenchLuxembourg
	self with: 'fr-lu'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
frenchMonaco
	self with: 'fr-mc'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
frenchSwitzerland
	self with: 'fr-ch'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
gaelic
	self with: 'gd'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
galician
	self with: 'gl'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
german
	self with: 'de'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
germanAustria
	self with: 'de-at'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
germanGermany
	self with: 'de-de'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
germanLiechtenstein
	self with: 'de-li'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
germanLuxembourg
	self with: 'de-lu'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
germanSwitzerland
	self with: 'de-ch'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
greek
	self with: 'el'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
hawaiian
	self with: 'haw'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
hungarian
	self with: 'hu'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
icelandic
	self with: 'is'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
indonesian
	self with: 'in'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
irish
	self with: 'ga'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
italian
	self with: 'it'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
italianItaly
	self with: 'it-it'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
italianSwitzerland
	self with: 'it-ch'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
japanese
	self with: 'ja'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
korean
	self with: 'ko'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
macedonian
	self with: 'mk'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
norwegian
	self with: 'no'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
polish
	self with: 'pl'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
portuguese
	self with: 'pt'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
portugueseBrazil
	self with: 'pt-br'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
portuguesePortugal
	self with: 'pt-pt'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
romanian
	self with: 'ro'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
romanianMoldova
	self with: 'ro-mo'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
romanianRomania
	self with: 'ro-ro'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
russian
	self with: 'ru'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
russianMoldova
	self with: 'ru-mo'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
russianRussia
	self with: 'ru-ru'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
serbian
	self with: 'sr'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
slovak
	self with: 'sk'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
slovenian
	self with: 'sl'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanish
	self with: 'es'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishArgentina
	self with: 'es-ar'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishBolivia
	self with: 'es-bo'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishChile
	self with: 'es-cl'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishColombia
	self with: 'es-co'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishCostaRica
	self with: 'es-cr'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishDominicanRepublic
	self with: 'es-do'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishEcuador
	self with: 'es-ec'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishElSalvador
	self with: 'es-sv'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishGuatemala
	self with: 'es-gt'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishHonduras
	self with: 'es-hn'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishMexico
	self with: 'es-mx'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishNicaragua
	self with: 'es-ni'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishPanama
	self with: 'es-pa'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishParaguay
	self with: 'es-py'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishPeru
	self with: 'es-pe'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishPuertoRico
	self with: 'es-pr'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishSpain
	self with: 'es-es'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishUruguay
	self with: 'es-uy'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
spanishVenezuela
	self with: 'es-ve'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
swedish
	self with: 'sv'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
swedishFinland
	self with: 'sv-fi'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
swedishSweden
	self with: 'sv-se'! !

!RRLanguageTag methodsFor: 'accessing' stamp: 'pmm 9/25/2006 16:27'!
tag
	^'language'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
turkish
	self with: 'tr'! !

!RRLanguageTag methodsFor: 'languages-generated' stamp: 'pmm 9/22/2006 15:27'!
ukranian
	self with: 'uk'! !

WATagBrush subclass: #RRSourceTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Core-Tags'!

!RRSourceTag methodsFor: 'accessing' stamp: 'pmm 9/29/2006 12:06'!
tag
	^'source'! !

!RRSourceTag methodsFor: 'attributes' stamp: 'pmm 9/29/2006 12:06'!
url: aString
	self attributeAt: 'url' put: aString! !

!WAHtmlRoot methodsFor: '*RSS-Core' stamp: 'pmm 4/6/2007 22:09'!
rss
	^self link beAlternate; beRss; yourself! !
